from abc import ABC
from typing import Optional, List
from uuid import UUID
from enum import Enum
from pydantic import BaseModel


class Solution(BaseModel):
    optimal_prices: List[int]
    objective: float
    status: int


class JobStatus(str, Enum):
    running = "running"
    cancelled = "cancelled"
    finished = "finished"


class JobType(str, Enum):
    revenue = "revenue"
    markdown = "markdown"


class Job(ABC, BaseModel):
    id: Optional[UUID]
    type: Optional[JobType]


class RevenueMaximisationJob(Job):
    prices: List[int]
    capacity: int
    demand_matrix: List[List[int]]


class MarkdownOptimisationJob(Job):
    prices: List[int]
    initial_inventory: int
    demand_matrix: List[List[int]]
    salvage_value: float
